@@ -1,5 +1,5 @@
 from huawei_lte_api.ApiGroup import ApiGroup
-from huawei_lte_api.Connection import GetResponseType
+from huawei_lte_api.Session import GetResponseType
 
 
 class MLog(ApiGroup):
@@ -8,4 +8,4 @@ class MLog(ApiGroup):
         Endpoint found by reverse engineering B310s-22 firmware, unknown usage
         :return:
         """
-        return self._connection.get('mlog/mobile-logger')
+        return self._session.get('mlog/mobile-logger')
